Battle of Wolf 359

Jean-Luc Picard
Battle of Wolf 359
A Recap of Events
2020-01-01
No section at all

- There is no section or no subsection set for this slide.
- In the status line, there should be nothing.

Now we do have them

- Now it's section “Foo”
- And subsection “Bar”
- This should show "Foo" / "Bar" below.

Resetting subsection

- Now it's section “Moo”
- But no subsection
- This should show only show “Moo” below.

Table of Contents

- 1 Foo

- 1.1 Bar

- 2 Moo
- 3 Introduction

- 3.1 Nomenclature

- 4 Included Topic

- 4.1 Introduction to included topic

- 5 Finalization

Table of Contents

- 5.1 After Include Subsection
- 5.2 Code Highlighting
- 5.3 Esc<>ping

Pausing Slides

- Pausing slides is easy! Acronyms too: WEPWired Equivalent Privacy

Pausing Slides

- Pausing slides is easy! Acronyms too: WEPWired Equivalent Privacy
- After the first pause! Another acronym: DESData Encryption Standard

Pausing Slides

- Pausing slides is easy! Acronyms too: WEPWired Equivalent Privacy
- After the first pause! Another acronym: DESData Encryption Standard
- This is after the second pause! Explaining AESAdvanced Encryption Standard-CBCCipher Block Chaining

That's the second slide

- This is a test!
- Should be slide number two!
- Next up: include!

Subtopic Title

- This is included from first presentation!

Subtopic Title

- This is included from first presentation!
- Second slide here!

After include

- We just included a sub-document
- This is the slide which directly follows an include.
- Fixed-width text is possible: 001122abcdef

Nested ULs

- Level 1 Moo
- Level 1 Koo
  - Nested 1
  - Nested 2

Even the best blade will rust and grow dull unless it is cared for.
— Klingon Proverb
Left/Right slide
This is on the left side. It's a long text, so it gets wrapped. You get a nice feeling as to how wide it is.
This is on the right side. It's a long text, so it gets wrapped. You get a nice feeling as to how wide it is.
Formula in Text

- Short Weierstrass:
- Some Sum:

In general, the short Weierstrass form is given as the formula and that's just great.

Long Formula

This is the long form:

While this is the short one for comparison:

Some Python Code

    if foo == "bar":
        print("foo was 'bar'")
        return getattr(self, "bar")
    else:
        print("foo was not 'bar'")
        return lambda x: tuple(x, "foo", 123)

Some C Code

    int main(int argc, char **argv) {
        printf("Foo: %d -> %p\n", argc, argv);
        return 0;
    }

Some Python Code from a File

    # This class is in its own file.
    class Foo():
        def __init__(self, moo):
            self._moo = moo

        @property
        def moo(self):
            return self._moo

Some Terminal

    $ ls /
    bin
    sbin

Some Terminal from a File

    $ cat foo
    This is terminal output.
    It comes from a file!

Quotation Marks

- “US style”
- «French style»
- „German style“
- ‘Single quotation marks’

Arrows

- → Right and long right ⟶
- ← Left and long left ⟵
- ↔ both and ⟷ both long and both double ⇔ and both double long ⟺
- ⇒ Double Right
- ⇐ Double Left
- ↵ Enter Key
- ⭍ Lightning

Symbols

- ⊕ XOR and ⊗ XMUL
- Operators ≤ < = ≠ >≥
- Infinity ∞

Emojis

- 🙂 😀 😉
- 🙁 ☹️ 😢
- 😐 😲 😮

Image Rendering
Image Animation
Image Animation
Image Animation
Escaped <> Characters

- This is verbatim: < >

Execution of scripts 1
Hello. This is a test! foo Fin.
Execution of scripts 2
Hello. This is a test! bar Fin.
Execution of scripts 3
Hello. This is a test! tt Fin.
Nested Tags
first bold bolditalics last
Thank you!
Any questions?
Acronyms

- AES: Advanced Encryption Standard
- CBC: Cipher Block Chaining
- DES: Data Encryption Standard
- WEP: Wired Equivalent Privacy

×
Feedback
Rating:
🤮 🙁 🙂 😁
Your name:
Email:
Comments: